@@ -61,9 +61,12 @@ def get_extension_from_file(file):
 
 
 # will return the file name from a file path
-def get_file_name_from_path(file):
+def get_file_name_from_path(file, with_extension=True):
     import ntpath
-    return ntpath.basename(file)
+    filename = ntpath.basename(file)
+    if not with_extension:
+        filename = filename[1:]
+    return filename
 
 
 # will remove a directory
@@ -105,11 +108,26 @@ def copy_list_of_files(files_list, dst):
         copy_file(file, dst)
 
 
-# will search for a file in a path
-def search_file(path_to_search, file_name):
+# will search for a file in a path by prefix, suffix, full name with/without an extension
+def search_files(path_to_search, full_name=None, prefix=None, suffix=None, by_extension=None):
     from pathlib import Path
     files = []
-    for filename in Path(path_to_search).glob('**/' + file_name):
+    search_queue = '**/'
+    if full_name:
+        search_queue += full_name
+        if by_extension:
+            search_queue += by_extension
+    else:
+        if prefix:
+            search_queue += f'{prefix}*'
+            if by_extension:
+                search_queue += by_extension
+        elif suffix:
+            search_queue += f'*{suffix}'
+            if by_extension:
+                search_queue += by_extension
+
+    for filename in Path(path_to_search).glob(search_queue):
         files.append(filename)
     return files
 
